@@ -5,21 +5,20 @@ OC.L10N.register(
     "Rename" : "ប្ដូរ​ឈ្មោះ",
     "Move" : "Move",
     "Delete" : "លុប",
-    "Save" : "រក្សាទុក",
+    "New" : "ថ្មី",
     "New folder" : "ថត​ថ្មី",
-    "Create" : "បង្កើត",
     "Cancel" : "បោះបង់",
     "Import" : "នាំយកចូល",
     "Export" : "នាំចេញ",
-    "URL" : "URL",
-    "Tags" : "ស្លាក",
-    "Notes" : "កំណត់​ចំណាំ",
-    "Sharing" : "ការ​ចែក​រំលែក",
-    "Owner" : "Owner",
-    "Share link" : "Share link",
-    "Select" : "Select",
     "Title" : "ចំណងជើង",
     "Link" : "Link",
-    "Folder" : "ថត"
+    "Tags" : "ស្លាក",
+    "Notes" : "កំណត់​ចំណាំ",
+    "Owner" : "Owner",
+    "Sharing" : "ការ​ចែក​រំលែក",
+    "Share link" : "Share link",
+    "Select" : "Select",
+    "Folder" : "ថត",
+    "Save" : "រក្សាទុក"
 },
 "nplurals=1; plural=0;");
