@@ -5,6 +5,7 @@ OC.L10N.register(
     "No file provided for import" : "가져올 파일을 지정하지 않았음",
     "Unsupported file type for import" : "지원하지 않는 가져오기 파일 형식",
     "Bookmarks shared by %s" : "%s이(가) 공유한 북마크 ",
+    "Recent Bookmarks" : "최근 북마크",
     "A Bookmark manager for Nextcloud" : "Nextcloud 북마크 관리자",
     "Select bookmark" : "북마크 선택",
     "Details" : "자세한 정보",
@@ -24,6 +25,7 @@ OC.L10N.register(
     "Enter folder title" : "폴더명을 입력하시오.",
     "Shared by {user}" : "{user}가 공유한",
     "Root folder" : "루트 폴더",
+    "Submit" : "제출",
     "Cancel" : "취소",
     "Recent" : "최근 항목",
     "Untagged" : "태그 지우기",
