@@ -178,9 +178,12 @@ class BookmarkMapper extends QBMapper {
 	/**
 	 * @param $userId
 	 * @param QueryParameters $params
-	 * @return array|Entity[]
+	 *
+	 * @return Entity[]
+	 *
+	 * @psalm-return array<array-key, Bookmark>
 	 */
-	public function findAll($userId, QueryParameters $params): array {
+	public function findAll(string $userId, QueryParameters $params): array {
 		$qb = $this->db->getQueryBuilder();
 		$bookmark_cols = array_map(static function ($c) {
 			return 'b.' . $c;
@@ -194,15 +197,9 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
-				$qb->expr()->eq('tr.id', 'b.id'),
-				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
-			))
+			->leftJoin('b', 'bookmarks_tree', 'tr', 'tr.id = b.id AND tr.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
-			->leftJoin('tr', 'bookmarks_tree', 'tr2', $qb->expr()->andX(
-				$qb->expr()->eq('tr2.id', 'tr.parent_folder'),
-				$qb->expr()->eq('tr2.type', $qb->createPositionalParameter(TreeMapper::TYPE_FOLDER))
-			))
+			->leftJoin('tr', 'bookmarks_tree', 'tr2', 'tr2.id = tr.parent_folder AND tr2.type = '. $qb->createPositionalParameter(TreeMapper::TYPE_FOLDER))
 			->leftJoin('tr2', 'bookmarks_shared_folders', 'sf2', $qb->expr()->eq('tr2.parent_folder', 'sf.folder_id'))
 			->where(
 				$qb->expr()->orX(
@@ -391,10 +388,7 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
-				$qb->expr()->eq('b.id', 'tr.id'),
-				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
-			))
+			->leftJoin('b', 'bookmarks_tree', 'tr', 'b.id = tr.id AND tr.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
 			->where($qb->expr()->orX(
 				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
@@ -415,10 +409,7 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
-				$qb->expr()->eq('b.id', 'tr.id'),
-				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
-			))
+			->leftJoin('b', 'bookmarks_tree', 'tr', 'b.id = tr.id AND tr.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
 			->leftJoin('tr', 'bookmarks_shared_folders', 'sf', $qb->expr()->eq('tr.parent_folder', 'sf.folder_id'))
 			->where($qb->expr()->orX(
 				$qb->expr()->eq('b.user_id', $qb->createPositionalParameter($userId)),
@@ -430,14 +421,20 @@ class BookmarkMapper extends QBMapper {
 	}
 
 	/**
+	 * 	 *
 	 *
-	 * @param $token
+	 * @param string $token
 	 * @param QueryParameters $params
-	 * @return array|Entity[]
+	 *
+	 *
+	 * @return Entity[]
+	 *
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
+	 *
+	 * @psalm-return array<array-key, Bookmark>
 	 */
-	public function findAllInPublicFolder($token, QueryParameters $params): array {
+	public function findAllInPublicFolder(string $token, QueryParameters $params): array {
 		/** @var PublicFolder $publicFolder */
 		$publicFolder = $this->publicMapper->find($token);
 
@@ -454,14 +451,8 @@ class BookmarkMapper extends QBMapper {
 
 		$qb
 			->from('bookmarks', 'b')
-			->leftJoin('b', 'bookmarks_tree', 'tr', $qb->expr()->andX(
-				$qb->expr()->eq('tr.id', 'b.id'),
-				$qb->expr()->eq('tr.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
-			))
-			->leftJoin('tr', 'bookmarks_tree', 'tr2', $qb->expr()->andX(
-				$qb->expr()->eq('tr2.id', 'tr.parent_folder'),
-				$qb->expr()->eq('tr2.type', $qb->createPositionalParameter(TreeMapper::TYPE_FOLDER))
-			))
+			->leftJoin('b', 'bookmarks_tree', 'tr', 'tr.id = b.id AND tr.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
+			->leftJoin('tr', 'bookmarks_tree', 'tr2', 'tr2.id = tr.parent_folder AND tr2.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_FOLDER))
 			->where(
 				$qb->expr()->orX(
 					$qb->expr()->eq('tr.parent_folder', $qb->createPositionalParameter($publicFolder->getFolderId(), IQueryBuilder::PARAM_INT)),
@@ -484,7 +475,10 @@ class BookmarkMapper extends QBMapper {
 	/**
 	 * @param int $limit
 	 * @param int $stalePeriod
-	 * @return array|Entity[]
+	 *
+	 * @return Entity[]
+	 *
+	 * @psalm-return array<array-key, Bookmark>
 	 */
 	public function findPendingPreviews(int $limit, int $stalePeriod): array {
 		$qb = $this->db->getQueryBuilder();
@@ -498,7 +492,9 @@ class BookmarkMapper extends QBMapper {
 
 	/**
 	 * @param Entity $entity
-	 * @return Entity|void
+	 *
+	 * @return Entity
+	 * @psalm-return Bookmark
 	 */
 	public function delete(Entity $entity): Entity {
 		$this->eventDispatcher->dispatch(
@@ -585,9 +581,11 @@ class BookmarkMapper extends QBMapper {
 
 	/**
 	 * @param $userId
+	 * @param string $userId
+	 *
 	 * @return int
 	 */
-	public function countBookmarksOfUser($userId) : int {
+	public function countBookmarksOfUser(string $userId) : int {
 		$qb = $this->db->getQueryBuilder();
 		$qb
 			->select($qb->func()->count('id'))
@@ -619,10 +617,7 @@ class BookmarkMapper extends QBMapper {
 	 * @param IQueryBuilder $qb
 	 */
 	private function _selectFolders(IQueryBuilder $qb): void {
-		$qb->leftJoin('b', 'bookmarks_tree', 'tree', $qb->expr()->andX(
-			$qb->expr()->eq('b.id', 'tree.id'),
-			$qb->expr()->eq('tree.type', $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
-		));
+		$qb->leftJoin('b', 'bookmarks_tree', 'tree', 'b.id =tree.id AND tree.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK));
 		if ($this->getDbType() === 'pgsql') {
 			$folders = $qb->createFunction('array_to_string(array_agg(' . $qb->getColumnName('tree.parent_folder') . "), ',')");
 		} else {
