@@ -1,3 +1,9 @@
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ *
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
+ */
+
 import Vue from 'vue'
 import axios from '@nextcloud/axios'
 
@@ -19,6 +25,7 @@ export const mutations = {
 	SET_ARCHIVED_COUNT: 'SET_ARCHIVED_COUNT',
 	SET_TAGS: 'SET_TAGS',
 	RENAME_TAG: 'RENAME_TAG',
+	REMOVE_TAG: 'REMOVE_TAG',
 	INCREMENT_PAGE: 'INCREMENT_PAGE',
 	RESET_PAGE: 'RESET_PAGE',
 	SET_QUERY: 'SET_QUERY',
@@ -75,6 +82,13 @@ export default {
 			}))
 		})
 	},
+	[mutations.REMOVE_TAG](state, oldTag) {
+		state.bookmarks.forEach((bookmark) => {
+			Vue.set(bookmark, 'tags', bookmark.tags.filter((tag) => {
+				return tag !== oldTag
+			}))
+		})
+	},
 	[mutations.DISPLAY_NEW_BOOKMARK](state, display) {
 		state.displayNewBookmark = display
 		if (display) {
